===========================
Selenium FB Group Automator
===========================


.. image:: https://img.shields.io/pypi/v/selenium_fb_group_automator.svg
        :target: https://pypi.python.org/pypi/selenium_fb_group_automator

.. image:: https://img.shields.io/travis/prince-mishra/selenium_fb_group_automator.svg
        :target: https://travis-ci.com/prince-mishra/selenium_fb_group_automator

.. image:: https://readthedocs.org/projects/selenium-fb-group-automator/badge/?version=latest
        :target: https://selenium-fb-group-automator.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/prince-mishra/selenium_fb_group_automator/shield.svg
     :target: https://pyup.io/repos/github/prince-mishra/selenium_fb_group_automator/
     :alt: Updates



Manage Facebook Groups using Selenium


* Free software: MIT license
* Documentation: https://selenium-fb-group-automator.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
